#[repr(transparent)]pub struct ProviderRow {
inner: TypedObjectRef<ProviderRow, <ProviderRow as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<ProviderRow, <ProviderRow as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl ProviderRow
impl ProviderRow
pub fn provider(&self) -> <OnceCell<Provider> as Property>::Value
Sourcepub fn connect_provider_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_provider_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the provider property
Sourcepub fn notify_provider(&self)
pub fn notify_provider(&self)
Notify listeners of a change in the provider property
Sourceimpl ProviderRow
impl ProviderRow
pub fn new(provider: &Provider) -> Self
pub fn connect_changed<F>(&self, callback: F) -> SignalHandlerIdwhere
F: Fn(&Self) + 'static,
fn tick_progressbar(&self)
fn setup_widget(&self)